@@ -16,24 +16,21 @@ mod tests {
         let mut sys = System::new();
         sys.refresh_system();
         // We don't want to test on unsupported systems.
-        if crate::MIN_USERS > 0 {
-            assert!(sys.get_total_memory() != 0);
-            assert!(sys.get_free_memory() != 0);
+        if System::IS_SUPPORTED {
+            assert!(sys.total_memory() != 0);
+            assert!(sys.free_memory() != 0);
         }
-        assert!(sys.get_total_memory() >= sys.get_free_memory());
-        assert!(sys.get_total_swap() >= sys.get_free_swap());
+        assert!(sys.total_memory() >= sys.free_memory());
+        assert!(sys.total_swap() >= sys.free_swap());
     }
 
     #[test]
     fn test_refresh_process() {
         let mut sys = System::new();
-        assert!(
-            sys.get_processes().is_empty(),
-            "no process should be listed!"
-        );
+        assert!(sys.processes().is_empty(), "no process should be listed!");
         sys.refresh_processes();
-        if crate::MIN_USERS > 0 {
-            // We don't want to test on unsupported systems.
+        // We don't want to test on unsupported systems.
+        if System::IS_SUPPORTED {
             assert!(
                 sys.refresh_process(utils::get_current_pid().expect("failed to get current pid")),
                 "process not listed",
@@ -45,13 +42,10 @@ mod tests {
     fn test_get_process() {
         let mut sys = System::new();
         sys.refresh_processes();
-        if let Some(p) =
-            sys.get_process(utils::get_current_pid().expect("failed to get current pid"))
-        {
+        if let Some(p) = sys.process(utils::get_current_pid().expect("failed to get current pid")) {
             assert!(p.memory() > 0);
-        } else if crate::MIN_USERS > 0 {
-            // We don't want to test on unsupported systems.
-            panic!("didn't find process");
+        } else {
+            assert!(!System::IS_SUPPORTED);
         }
     }
 
@@ -70,16 +64,13 @@ mod tests {
 
         let mut sys = System::new();
         sys.refresh_processes();
-        if let Some(p) =
-            sys.get_process(utils::get_current_pid().expect("failed to get current pid"))
-        {
+        if let Some(p) = sys.process(utils::get_current_pid().expect("failed to get current pid")) {
             p.foo(); // If this doesn't compile, it'll simply mean that the Process type
                      // doesn't implement the Send trait.
             p.bar(); // If this doesn't compile, it'll simply mean that the Process type
                      // doesn't implement the Sync trait.
-        } else if crate::MIN_USERS > 0 {
-            // We don't want to test on unsupported systems.
-            panic!("didn't find process");
+        } else {
+            assert!(!System::IS_SUPPORTED);
         }
     }
 
@@ -87,8 +78,19 @@ mod tests {
     fn check_hostname_has_no_nuls() {
         let sys = System::new();
 
-        if let Some(hostname) = sys.get_host_name() {
+        if let Some(hostname) = sys.host_name() {
             assert!(!hostname.contains('\u{0}'))
         }
     }
+
+    #[test]
+    fn check_uptime() {
+        let sys = System::new();
+        let uptime = sys.uptime();
+        if System::IS_SUPPORTED {
+            std::thread::sleep(std::time::Duration::from_millis(1000));
+            let new_uptime = sys.uptime();
+            assert!(uptime < new_uptime);
+        }
+    }
 }
