@@ -12,30 +12,34 @@ use std::{ffi::OsStr, path::Path};
 pub struct Disk {}
 
 impl DiskExt for Disk {
-    fn get_type(&self) -> DiskType {
+    fn type_(&self) -> DiskType {
         unreachable!()
     }
 
-    fn get_name(&self) -> &OsStr {
+    fn name(&self) -> &OsStr {
         unreachable!()
     }
 
-    fn get_file_system(&self) -> &[u8] {
+    fn file_system(&self) -> &[u8] {
         &[]
     }
 
-    fn get_mount_point(&self) -> &Path {
+    fn mount_point(&self) -> &Path {
         Path::new("")
     }
 
-    fn get_total_space(&self) -> u64 {
+    fn total_space(&self) -> u64 {
         0
     }
 
-    fn get_available_space(&self) -> u64 {
+    fn available_space(&self) -> u64 {
         0
     }
 
+    fn is_removable(&self) -> bool {
+        false
+    }
+
     fn refresh(&mut self) -> bool {
         true
     }
